@@ -1,8 +1,8 @@
 #' @title Spectral Graph Matching Methods: Umeyama Algorithm
 #' @rdname gm_Umeyama
 #'
-#' @param A A matrix, 'igraph' object, or list of either.
-#' @param B A matrix, 'igraph' object, or list of either.
+#' @param A A matrix, igraph object, or list of either.
+#' @param B A matrix, igraph object, or list of either.
 #' @param similarity A matrix. An \code{n-by-n} matrix containing vertex similarities.
 #' @param seeds A vector of integers or logicals, a matrix or a data frame. If
 #'   the seed pairs have the same indices in both graphs then seeds can be a
@@ -10,10 +10,17 @@
 #'   or a data frame, with the first column being the indices of \eqn{G_1} and
 #'   the second column being the corresponding indices of \eqn{G_2}.
 #'
-#' @return \code{graph_match_Umeyama} returns a list of graph matching
-#'   results, including the graph matching formula, a data frame containing the
-#'   matching correspondence between \eqn{G_1} and \eqn{G_2} named \code{corr_A}
-#'   and \code{corr_B} and seeds.
+#' @return \code{graph_match_Umeyama} returns an object of class "\code{\link{graphMatch}}" which is a list
+#'   containing the following components:
+#'
+#'   \describe{
+#'     \item{corr_A}{matching correspondence in \eqn{G_1}}
+#'     \item{corr_B}{matching correspondence in \eqn{G_2}}
+#'     \item{soft}{the functional similarity score matrix with which one can extract
+#'       more than one matching candidates}
+#'     \item{lap_method}{Choice for solving the LAP}
+#'     \item{seeds}{a vector of logicals indicating if the corresponding vertex is a seed}
+#'   }
 #'
 #' @references S. Umeyama (1988), \emph{An eigendecomposition approach to weighted
 #'   graph matching problems}. IEEE TPAMI. USA, pages 695-703.
@@ -25,24 +32,29 @@
 #' g2 <- G$graph2
 #' startm <- matrix(0, 10, 10)
 #' diag(startm)[1:4] <- 1
-#' graph_match_Umeyama(g1, g2, similarity = startm)
 #'
-#' @export
+#' GM_Umeyama <- gm(g1, g2, similarity = startm, method = "Umeyama")
+#' GM_Umeyama
+#' # generate the corresponding permutation matrix
+#' GM_Umeyama[]
 #'
+#' summary(GM_Umeyama, g1, g2)
+#' # visualize the edge-wise matching performance
+#' plot(g1, g2, GM_Umeyama)
+#' plot(g1[], g2[], GM_Umeyama)
+#'
+#'
+#' @keywords internal
 graph_match_Umeyama <- function(A, B, seeds = NULL,
                                 similarity = NULL){
 
-  graph_pair <- check_graph(A, B)
-  A <- graph_pair[[1]]
-  B <- graph_pair[[2]]
-  totv1 <- graph_pair$totv1
-  totv2 <- graph_pair$totv2
+  totv1 <- nrow(A[[1]])
+  totv2 <- nrow(B[[1]])
+  nv <- max(totv1, totv2)
+  nonseeds <- check_seeds(seeds, nv)$nonseeds
+  ns <- nrow(seeds)
+  nn <- nv - ns
   nc <- length(A)
-
-  seeds <- check_seeds(seeds, nv = max(totv1, totv2))
-  nonseeds <- seeds$nonseeds
-  seeds <- seeds$seeds
-  similarity <- check_sim(similarity, seeds, nonseeds, totv1, totv2)
   Grad <- 0
 
   for( ch in 1:nc ){
@@ -76,9 +88,15 @@ graph_match_Umeyama <- function(A, B, seeds = NULL,
   corr <- data.frame(corr_A = c(seeds$A, nonseeds$A), corr_B = c(seeds$B, nonseeds$B[ind]))
   corr <- corr[order(corr$corr_A),]
   cl <- match.call()
-  z <- list(
-    call = cl,
+
+  graphMatch(
     corr = corr,
-    seeds = seeds)
-  z
+    nnodes = c(totv1, totv2),
+    call = cl,
+    detail = list(
+      lap_method = lap_method,
+      seeds = seeds,
+      soft = Grad
+    )
+  )
 }
