@@ -1,19 +1,20 @@
-#' @title Find the largest common connected subgraph(LCCS)
+#' @title Find the largest common connected subgraph (LCCS) of two graphs
 #'
-#' @description Assume two aligned graphs, find the largest common connect subgraph of these
-#' two graphs, which is an induced connected subgraph of both graphs that has as many vertices
-#' as possible.
+#' @description Find the largest common connected subgraphs of
+#' two matched graphs, which is an induced connected subgraph of both graphs
+#' that has as many vertices as possible.
+#' The \code{largest_cc} function returns the largest connected subgraph of a single graph.
 #'
-#' @param A A matrix or an 'igraph' object. Adjacency matrix of \eqn{G_1}.
-#' @param B A matrix or an 'igraph' object. Adjacency matrix of \eqn{G_2}.
-#' @param min_degree A number. Defines the level of connectedness of the 
-#' obtained largest common connected subgraph. The induced subgraph is 
-#' a graph with a minimum degree of vertices more than min_degree.
+#' @param A A matrix or an igraph object. See \link{check_graph}. Must be single-layer.
+#' @param B A matrix or an igraph object. See \link{check_graph}. Must be single-layer.
+#' @param min_degree A number. Defines the level of connectedness of the
+#' obtained largest common connected subgraph. The induced subgraph is
+#' a graph with a minimum vertex-degree of at least min_degree.
 #'
 #' @rdname largest_common_cc
 #'
 #' @return \code{largest_common_cc} returns the common largest connected subgraphs of
-#' two aligned graphs in the 'igraph' object form and a logical vector indicating which vertices in
+#' two aligned graphs in the igraph object form and a logical vector indicating which vertices in
 #' the original graphs remain in the induced subgraph.
 #'
 #' @examples
@@ -33,11 +34,11 @@
 #' @export
 #'
 largest_common_cc <- function(A, B, min_degree = 1){
-  graph_pair <- check_graph(A, B)
+  graph_pair <- check_graph(A, B, as_list = FALSE)
   A <- graph_pair[[1]]
   B <- graph_pair[[2]]
-  A <- graph_from_adjacency_matrix(as.matrix(A[[1]]))
-  B <- graph_from_adjacency_matrix(as.matrix(B[[1]]))
+  A <- igraph::graph_from_adjacency_matrix(A)
+  B <- igraph::graph_from_adjacency_matrix(B)
   keep <- rep(TRUE, igraph::vcount(A))
   while (!(igraph::is_connected(A) && igraph::is_connected(B))){
     cc1 <- igraph::components(A)
@@ -67,3 +68,23 @@ largest_common_cc <- function(A, B, min_degree = 1){
 
   list(g1 = A, g2 = B, keep = keep)
 }
+
+#' @rdname largest_common_cc
+#'
+#' @examples
+#'
+#' g <- igraph::sample_gnp(100, .01)
+#' lcc <- largest_cc(g)
+#' # induced subgraph
+#' lcc$g
+#' # label of vertices of the induced subgraph in the original graph
+#' igraph::V(g)[lcc$keep]
+#'
+#' @export
+largest_cc <- function(A){
+  g <- igraph::graph_from_adjacency_matrix(check_single_graph(A, as_list = FALSE))
+  c <- igraph::components(g)
+  lc <- which.max(c$csize)
+  keep <- c$membership == lc
+  list(g = igraph::induced_subgraph(g, V(g)[keep]), keep = keep)
+}
